Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-04-24 18:45:49 +0400
committerCampbell Barton <ideasman42@gmail.com>2011-04-24 18:45:49 +0400
commitfd45310dfe30952081ef51f80e62543664ca84a5 (patch)
tree1c9babdc970a69ce1ebc569904ddd7f6c893295f /source/blender/blenloader/BLO_readfile.h
parent8fdebf24f4fe405c77f13a72c45cf0f8e6bc1f3f (diff)
fix crash [#27158] Appending crash with preview.
Diffstat (limited to 'source/blender/blenloader/BLO_readfile.h')
-rw-r--r--source/blender/blenloader/BLO_readfile.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/source/blender/blenloader/BLO_readfile.h b/source/blender/blenloader/BLO_readfile.h
index 891dc47b4ae..22083eda1c8 100644
--- a/source/blender/blenloader/BLO_readfile.h
+++ b/source/blender/blenloader/BLO_readfile.h
@@ -148,7 +148,7 @@ BLO_blendhandle_from_memory(
*
* @param bh The blendhandle to access.
* @param ofblocktype The type of names to get.
* @param totnames The length of the returned list.
* @return A BLI_linklist of strings. The string links
* should be freed with malloc.
*/
@@ -156,7 +156,7 @@ BLO_blendhandle_from_memory(
BLO_blendhandle_get_datablock_names(
BlendHandle *bh,
int ofblocktype,
- int *totnames);
+ int *tot_names);
/**
* Gets the previews of all the datablocks in a file
@@ -165,13 +165,15 @@ BLO_blendhandle_get_datablock_names(
*
* @param bh The blendhandle to access.
* @param ofblocktype The type of names to get.
+ * @param tot_prev The length of the returned list.
* @return A BLI_linklist of PreviewImage. The PreviewImage links
* should be freed with malloc.
*/
struct LinkNode*
BLO_blendhandle_get_previews(
BlendHandle *bh,
- int ofblocktype);
+ int ofblocktype,
+ int *tot_prev);
/**
* Gets the names of all the datablock groups in a
@@ -148,7 +148,7 @@ BLO_blendhandle_from_memory(
* @param bh The blendhandle to access.
* @param ofblocktype The type of names to get.
- * @param totnames The length of the returned list.
+ * @param tot_names The length of the returned list.
* @return A BLI_linklist of strings. The string links
* should be freed with malloc.